@@ -34,6 +34,9 @@ class ModelConfig:
     model: tf.Module | TrainableProbabilisticModel
     """ The :class:`~trieste.models.TrainableProbabilisticModel`, or the model to wrap in one. """
 
+    model_args: dict[str, Any] = field(default_factory=lambda: {})
+    """ The keyword arguments to pass to the model wrapper. """
+
     optimizer: gpflow.optimizers.Scipy | tf.optimizers.Optimizer = field(
         default_factory=_default_optimizer
     )
@@ -76,7 +79,7 @@ class ModelConfig:
 
         for model_type, model_interface in supported_models.items():
             if isinstance(self.model, model_type):
-                return model_interface(self.model, optimizer)
+                return model_interface(self.model, optimizer, **self.model_args)  # type: ignore
 
         raise NotImplementedError(f"Not supported type {type(self.model)}")
 
